package javax.swing;

import javax.accessibility.AccessibleRole;
import javax.accessibility.AccessibleStateSet;
import javax.accessibility.AccessibleValue;
import java.io.Serializable;
import javax.accessibility.AccessibleContext;
import java.io.IOException;
import java.io.ObjectOutputStream;
import java.awt.Color;
import javax.swing.plaf.UIResource;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.util.Hashtable;
import java.util.Enumeration;
import java.awt.Component;
import java.awt.Image;
import java.awt.Font;
import javax.accessibility.AccessibleState;
import javax.swing.plaf.SliderUI;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import java.util.Dictionary;
import javax.accessibility.Accessible;

public class JSlider extends JComponent implements SwingConstants, Accessible
{
    private static final String uiClassID = "SliderUI";
    private boolean paintTicks;
    private boolean paintTrack;
    private boolean paintLabels;
    private boolean isInverted;
    protected BoundedRangeModel sliderModel;
    protected int majorTickSpacing;
    protected int minorTickSpacing;
    protected boolean snapToTicks;
    boolean snapToValue;
    protected int orientation;
    private Dictionary labelTable;
    protected ChangeListener changeListener;
    protected transient ChangeEvent changeEvent;
    
    private void checkOrientation(int n) {
        switch (n) {
            case 0:
            case 1: {
                return;
            }
            default: {
                throw new IllegalArgumentException("orientation must be one of: VERTICAL, HORIZONTAL");
            }
        }
    }
    
    public JSlider() {
        this(0, 0, 100, 50);
    }
    
    public JSlider(int n) {
        this(n, 0, 100, 50);
    }
    
    public JSlider(int n, int n2) {
        this(0, n, n2, (n + n2) / 2);
    }
    
    public JSlider(int n, int n2, int n3) {
        this(0, n, n2, n3);
    }
    
    public JSlider(int orientation, int n, int n2, int n3) {
        this.paintTicks = false;
        this.paintTrack = true;
        this.paintLabels = false;
        this.isInverted = false;
        this.snapToTicks = false;
        this.snapToValue = true;
        this.changeListener = this.createChangeListener();
        this.changeEvent = null;
        this.checkOrientation(orientation);
        this.orientation = orientation;
        this.setModel(new DefaultBoundedRangeModel(n3, 0, n, n2));
        this.updateUI();
    }
    
    public JSlider(BoundedRangeModel model) {
        this.paintTicks = false;
        this.paintTrack = true;
        this.paintLabels = false;
        this.isInverted = false;
        this.snapToTicks = false;
        this.snapToValue = true;
        this.changeListener = this.createChangeListener();
        this.changeEvent = null;
        this.orientation = 0;
        this.setModel(model);
        this.updateUI();
    }
    
    public SliderUI getUI() {
        return (SliderUI)this.ui;
    }
    
    public void setUI(SliderUI ui) {
        super.setUI(ui);
    }
    
    @Override
    public void updateUI() {
        this.setUI((SliderUI)UIManager.getUI(this));
        this.updateLabelUIs();
    }
    
    @Override
    public String getUIClassID() {
        return "SliderUI";
    }
    
    protected ChangeListener createChangeListener() {
        return new JSlider.ModelListener();
    }
    
    public void addChangeListener(ChangeListener l) {
        this.listenerList.add(ChangeListener.class, l);
    }
    
    public void removeChangeListener(ChangeListener l) {
        this.listenerList.remove(ChangeListener.class, l);
    }
    
    public ChangeListener[] getChangeListeners() {
        return (ChangeListener[])this.listenerList.getListeners(ChangeListener.class);
    }
    
    protected void fireStateChanged() {
        Object[] listenerList = this.listenerList.getListenerList();
        for (int i = listenerList.length - 2; i >= 0; i -= 2) {
            if (listenerList[i] == ChangeListener.class) {
                if (this.changeEvent == null) {
                    this.changeEvent = new ChangeEvent(this);
                }
                ((ChangeListener)listenerList[i + 1]).stateChanged(this.changeEvent);
            }
        }
    }
    
    public BoundedRangeModel getModel() {
        return this.sliderModel;
    }
    
    public void setModel(BoundedRangeModel sliderModel) {
        BoundedRangeModel model = this.getModel();
        if (model != null) {
            model.removeChangeListener(this.changeListener);
        }
        if ((this.sliderModel = sliderModel) != null) {
            sliderModel.addChangeListener(this.changeListener);
        }
        if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleValue", (model == null) ? null : Integer.valueOf(model.getValue()), (sliderModel == null) ? null : Integer.valueOf(sliderModel.getValue()));
        }
        this.firePropertyChange("model", model, this.sliderModel);
    }
    
    public int getValue() {
        return this.getModel().getValue();
    }
    
    public void setValue(int value) {
        BoundedRangeModel model = this.getModel();
        int value2 = model.getValue();
        if (value2 == value) {
            return;
        }
        model.setValue(value);
        if (this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleValue", Integer.valueOf(value2), Integer.valueOf(model.getValue()));
        }
        return;
    }
    
    public int getMinimum() {
        return this.getModel().getMinimum();
    }
    
    public void setMinimum(int n) {
        int minimum = this.getModel().getMinimum();
        this.getModel().setMinimum(n);
        this.firePropertyChange("minimum", Integer.valueOf(minimum), Integer.valueOf(n));
    }
    
    public int getMaximum() {
        return this.getModel().getMaximum();
    }
    
    public void setMaximum(int n) {
        int maximum = this.getModel().getMaximum();
        this.getModel().setMaximum(n);
        this.firePropertyChange("maximum", Integer.valueOf(maximum), Integer.valueOf(n));
    }
    
    public boolean getValueIsAdjusting() {
        return this.getModel().getValueIsAdjusting();
    }
    
    public void setValueIsAdjusting(boolean valueIsAdjusting) {
        BoundedRangeModel model = this.getModel();
        int valueIsAdjusting2 = model.getValueIsAdjusting();
        model.setValueIsAdjusting(valueIsAdjusting);
        if (valueIsAdjusting2 != (valueIsAdjusting ? 1 : 0) && this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", valueIsAdjusting2 ? AccessibleState.BUSY : null, valueIsAdjusting ? AccessibleState.BUSY : null);
        }
    }
    
    public int getExtent() {
        return this.getModel().getExtent();
    }
    
    public void setExtent(int extent) {
        this.getModel().setExtent(extent);
    }
    
    public int getOrientation() {
        return this.orientation;
    }
    
    public void setOrientation(int orientation) {
        this.checkOrientation(orientation);
        int orientation2 = this.orientation;
        this.firePropertyChange("orientation", orientation2, this.orientation = orientation);
        if (orientation2 != orientation && this.accessibleContext != null) {
            this.accessibleContext.firePropertyChange("AccessibleState", (orientation2 == 1) ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL, (orientation == 1) ? AccessibleState.VERTICAL : AccessibleState.HORIZONTAL);
        }
        if (orientation != orientation2) {
            this.revalidate();
        }
    }
    
    @Override
    public void setFont(Font font) {
        super.setFont(font);
        this.updateLabelSizes();
    }
    
    @Override
    public boolean imageUpdate(Image img, int infoflags, int x, int y, int w, int h) {
        if (!this.isShowing()) {
            return false;
        }
        Enumeration<Object> elements = this.labelTable.elements();
        while (elements.hasMoreElements()) {
            Component component = (Component)elements.nextElement();
            if ((component instanceof JLabel)) {
                JLabel label = (JLabel)component;
                if (SwingUtilities.doesIconReferenceImage(label.getIcon(), img) || SwingUtilities.doesIconReferenceImage(label.getDisabledIcon(), img)) {
                    return super.imageUpdate(img, infoflags, x, y, w, h);
                }
                continue;
            }
            else {
                continue;
            }
        }
        return false;
    }
    
    public Dictionary getLabelTable() {
        return this.labelTable;
    }
    
    public void setLabelTable(Dictionary labelTable) {
        Dictionary<Object, Object> labelTable2 = this.labelTable;
        this.labelTable = labelTable;
        this.updateLabelUIs();
        this.firePropertyChange("labelTable", labelTable2, this.labelTable);
        if (labelTable != labelTable2) {
            this.revalidate();
            this.repaint();
        }
    }
    
    protected void updateLabelUIs() {
        Dictionary<Object, Object> labelTable = this.getLabelTable();
        if (labelTable == null) {
            return;
        }
        Enumeration<Object> keys = labelTable.keys();
        while (keys.hasMoreElements()) {
            JComponent component = (JComponent)labelTable.get(keys.nextElement());
            component.updateUI();
            component.setSize(component.getPreferredSize());
        }
        return;
    }
    
    private void updateLabelSizes() {
        Dictionary<Object, Object> labelTable = this.getLabelTable();
        if (labelTable != null) {
            Enumeration<Object> elements = labelTable.elements();
            while (elements.hasMoreElements()) {
                JComponent component = (JComponent)elements.nextElement();
                component.setSize(component.getPreferredSize());
            }
        }
    }
    
    public Hashtable createStandardLabels(int n) {
        return this.createStandardLabels(n, this.getMinimum());
    }
    
    public Hashtable createStandardLabels(int n, int n2) {
        if (n2 > this.getMaximum() || n2 < this.getMinimum()) {
            throw new IllegalArgumentException("Slider label start point out of range.");
        }
        if (n <= 0) {
            throw new IllegalArgumentException("Label incremement must be > 0");
        }
        class SmartHashtable extends Hashtable<Object, Object> implements PropertyChangeListener
        {
            int increment = n;
            int start = n2;
            boolean startAtMin;
            
            public SmartHashtable(int start) {
                this.increment = 0;
                this.start = 0;
                this.startAtMin = false;
                this.startAtMin = (start == JSlider.this.getMinimum());
                this.createLabels();
            }
            
            @Override
            public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
                if (propertyChangeEvent.getPropertyName().equals("minimum") && this.startAtMin) {
                    this.start = JSlider.this.getMinimum();
                }
                if (propertyChangeEvent.getPropertyName().equals("minimum") || propertyChangeEvent.getPropertyName().equals("maximum")) {
                    Enumeration<Object> keys = JSlider.this.getLabelTable().keys();
                    Hashtable<Object, Object> hashtable = new Hashtable();
                    while (keys.hasMoreElements()) {
                        Object nextElement = keys.nextElement();
                        Object value = JSlider.this.labelTable.get(nextElement);
                        if (!(value instanceof JSlider.1SmartHashtable.LabelUIResource)) {
                            hashtable.put(nextElement, value);
                        }
                        else {
                            continue;
                        }
                    }
                    this.clear();
                    this.createLabels();
                    Enumeration<Object> keys2 = hashtable.keys();
                    while (keys2.hasMoreElements()) {
                        Object nextElement2 = keys2.nextElement();
                        this.put(nextElement2, hashtable.get(nextElement2));
                    }
                    ((JSlider)propertyChangeEvent.getSource()).setLabelTable(this);
                }
            }
            
            void createLabels() {
                for (int i = this.start; i <= JSlider.this.getMaximum(); i += this.increment) {
                    this.put(Integer.valueOf(i), new JSlider.1SmartHashtable.LabelUIResource("" + i, 0));
                }
            }
            
            class LabelUIResource extends JLabel implements UIResource
            {
                public LabelUIResource(int n) {
                    super(s, n);
                    this.setName("Slider.label");
                }
                
                @Override
                public Font getFont() {
                    Font font = super.getFont();
                    if (font != null && !(font instanceof UIResource)) {
                        return font;
                    }
                    return JSlider.this.getFont();
                }
                
                @Override
                public Color getForeground() {
                    Color foreground = super.getForeground();
                    if (foreground != null && !(foreground instanceof UIResource)) {
                        return foreground;
                    }
                    if (!(JSlider.this.getForeground() instanceof UIResource)) {
                        return JSlider.this.getForeground();
                    }
                    return foreground;
                }
            }
        }
        JSlider.1SmartHashtable listener = new SmartHashtable();
        Dictionary<Object, Object> labelTable = this.getLabelTable();
        if (labelTable != null && labelTable instanceof PropertyChangeListener) {
            this.removePropertyChangeListener((PropertyChangeListener)labelTable);
        }
        this.addPropertyChangeListener(listener);
        return listener;
    }
    
    public boolean getInverted() {
        return this.isInverted;
    }
    
    public void setInverted(boolean isInverted) {
        int isInverted2 = this.isInverted;
        this.firePropertyChange("inverted", (boolean)isInverted2, this.isInverted = isInverted);
        if ((isInverted ? 1 : 0) != isInverted2) {
            this.repaint();
        }
    }
    
    public int getMajorTickSpacing() {
        return this.majorTickSpacing;
    }
    
    public void setMajorTickSpacing(int majorTickSpacing) {
        int majorTickSpacing2 = this.majorTickSpacing;
        this.majorTickSpacing = majorTickSpacing;
        if (this.labelTable == null && this.getMajorTickSpacing() > 0 && this.getPaintLabels()) {
            this.setLabelTable(this.createStandardLabels(this.getMajorTickSpacing()));
        }
        this.firePropertyChange("majorTickSpacing", majorTickSpacing2, this.majorTickSpacing);
        if (this.majorTickSpacing != majorTickSpacing2 && this.getPaintTicks()) {
            this.repaint();
        }
    }
    
    public int getMinorTickSpacing() {
        return this.minorTickSpacing;
    }
    
    public void setMinorTickSpacing(int minorTickSpacing) {
        int minorTickSpacing2 = this.minorTickSpacing;
        this.firePropertyChange("minorTickSpacing", minorTickSpacing2, this.minorTickSpacing = minorTickSpacing);
        if (this.minorTickSpacing != minorTickSpacing2 && this.getPaintTicks()) {
            this.repaint();
        }
    }
    
    public boolean getSnapToTicks() {
        return this.snapToTicks;
    }
    
    boolean getSnapToValue() {
        return this.snapToValue;
    }
    
    public void setSnapToTicks(boolean snapToTicks) {
        this.firePropertyChange("snapToTicks", this.snapToTicks, this.snapToTicks = snapToTicks);
    }
    
    void setSnapToValue(boolean snapToValue) {
        this.firePropertyChange("snapToValue", this.snapToValue, this.snapToValue = snapToValue);
    }
    
    public boolean getPaintTicks() {
        return this.paintTicks;
    }
    
    public void setPaintTicks(boolean paintTicks) {
        int paintTicks2 = this.paintTicks;
        this.firePropertyChange("paintTicks", (boolean)paintTicks2, this.paintTicks = paintTicks);
        if ((this.paintTicks ? 1 : 0) != paintTicks2) {
            this.revalidate();
            this.repaint();
        }
    }
    
    public boolean getPaintTrack() {
        return this.paintTrack;
    }
    
    public void setPaintTrack(boolean paintTrack) {
        int paintTrack2 = this.paintTrack;
        this.firePropertyChange("paintTrack", (boolean)paintTrack2, this.paintTrack = paintTrack);
        if ((this.paintTrack ? 1 : 0) != paintTrack2) {
            this.repaint();
        }
    }
    
    public boolean getPaintLabels() {
        return this.paintLabels;
    }
    
    public void setPaintLabels(boolean paintLabels) {
        int paintLabels2 = this.paintLabels;
        this.paintLabels = paintLabels;
        if (this.labelTable == null && this.getMajorTickSpacing() > 0) {
            this.setLabelTable(this.createStandardLabels(this.getMajorTickSpacing()));
        }
        this.firePropertyChange("paintLabels", (boolean)paintLabels2, this.paintLabels);
        if ((this.paintLabels ? 1 : 0) != paintLabels2) {
            this.revalidate();
            this.repaint();
        }
    }
    
    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        objectOutputStream.defaultWriteObject();
        if (this.getUIClassID().equals("SliderUI")) {
            int n = (byte)(JComponent.getWriteObjCounter(this) - 1);
            JComponent.setWriteObjCounter(this, (byte)n);
            if (n == 0 && this.ui != null) {
                this.ui.installUI(this);
            }
        }
    }
    
    @Override
    protected String paramString() {
        return super.paramString() + ",isInverted=" + (this.isInverted ? "true" : "false") + ",majorTickSpacing=" + this.majorTickSpacing + ",minorTickSpacing=" + this.minorTickSpacing + ",orientation=" + ((this.orientation == 0) ? "HORIZONTAL" : "VERTICAL") + ",paintLabels=" + (this.paintLabels ? "true" : "false") + ",paintTicks=" + (this.paintTicks ? "true" : "false") + ",paintTrack=" + (this.paintTrack ? "true" : "false") + ",snapToTicks=" + (this.snapToTicks ? "true" : "false") + ",snapToValue=" + (this.snapToValue ? "true" : "false");
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JSlider.AccessibleJSlider();
        }
        return this.accessibleContext;
    }
    
    private class ModelListener implements ChangeListener, Serializable
    {
        @Override
        public void stateChanged(ChangeEvent changeEvent) {
            JSlider.this.fireStateChanged();
        }
    }
    
    protected class AccessibleJSlider extends JComponent.AccessibleJComponent implements AccessibleValue
    {
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            AccessibleStateSet accessibleStateSet = super.getAccessibleStateSet();
            if (JSlider.this.getValueIsAdjusting()) {
                accessibleStateSet.add(AccessibleState.BUSY);
            }
            if (JSlider.this.getOrientation() == 1) {
                accessibleStateSet.add(AccessibleState.VERTICAL);
                return accessibleStateSet;
            }
            accessibleStateSet.add(AccessibleState.HORIZONTAL);
            return accessibleStateSet;
        }
        
        @Override
        public AccessibleRole getAccessibleRole() {
            return AccessibleRole.SLIDER;
        }
        
        @Override
        public AccessibleValue getAccessibleValue() {
            return this;
        }
        
        @Override
        public Number getCurrentAccessibleValue() {
            return Integer.valueOf(JSlider.this.getValue());
        }
        
        @Override
        public boolean setCurrentAccessibleValue(Number n) {
            if (n == null) {
                return false;
            }
            JSlider.this.setValue(n.intValue());
            return true;
        }
        
        @Override
        public Number getMinimumAccessibleValue() {
            return Integer.valueOf(JSlider.this.getMinimum());
        }
        
        @Override
        public Number getMaximumAccessibleValue() {
            BoundedRangeModel model = JSlider.this.getModel();
            return Integer.valueOf(model.getMaximum() - model.getExtent());
        }
    }
}
